summaryrefslogtreecommitdiff
path: root/src/script/api/script_enginelist.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/script/api/script_enginelist.cpp')
-rw-r--r--src/script/api/script_enginelist.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/script/api/script_enginelist.cpp b/src/script/api/script_enginelist.cpp
index cbbdb725e..6b0b512ab 100644
--- a/src/script/api/script_enginelist.cpp
+++ b/src/script/api/script_enginelist.cpp
@@ -7,7 +7,7 @@
* See the GNU General Public License for more details. You should have received a copy of the GNU General Public License along with OpenTTD. If not, see <http://www.gnu.org/licenses/>.
*/
/** @file script_enginelist.cpp Implementation of AIEngineList and friends. */
#include "../../stdafx.h"
#include "script_enginelist.hpp"
@@ -15,7 +15,7 @@
#include "../../engine_base.h"
#include "../../core/bitmath_func.hpp"
-AIEngineList::AIEngineList(AIVehicle::VehicleType vehicle_type)
+ScriptEngineList::ScriptEngineList(ScriptVehicle::VehicleType vehicle_type)
{
Engine *e;
FOR_ALL_ENGINES_OF_TYPE(e, (::VehicleType)vehicle_type) {
@@ -7,7 +7,7 @@
* See the GNU General Public License for more details. You should have received a copy of the GNU General Public License along with OpenTTD. If not, see <http://www.gnu.org/licenses/>.
*/
-/** @file script_enginelist.cpp Implementation of AIEngineList and friends. */
+/** @file script_enginelist.cpp Implementation of ScriptEngineList and friends. */
#include "../../stdafx.h"
#include "script_enginelist.hpp"